@@ -42,16 +42,18 @@ public:
 };
 
 PptpSettingWidget::PptpSettingWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent)
-    : SettingWidget(setting, parent), d_ptr(new PptpSettingWidgetPrivate)
+    : SettingWidget(setting, parent)
+    , d_ptr(new PptpSettingWidgetPrivate)
 {
     Q_D(PptpSettingWidget);
     d->ui.setupUi(this);
 
     d->setting = setting;
 
-    connect(d->ui.btnAdvanced, SIGNAL(clicked()), this, SLOT(doAdvancedDialog()));
-    connect (d->ui.cmbPasswordStorage, SIGNAL(currentIndexChanged(int)), this, SLOT(passwordTypeChanged(int)));
-    connect(d->ui.cb_showPassword, SIGNAL(toggled(bool)), this, SLOT(setShowPassword(bool)));
+    connect(d->ui.btnAdvanced, &QPushButton::clicked, this, &PptpSettingWidget::doAdvancedDialog);
+    connect(d->ui.cmbPasswordStorage, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &PptpSettingWidget::passwordTypeChanged);
+    connect(d->ui.cb_showPassword, &QCheckBox::toggled, this, &PptpSettingWidget::setShowPassword);
+
     d->advancedDlg = new QDialog(this);
     d->advancedWid = new QWidget(this);
     d->advUi.setupUi(d->advancedWid);
@@ -59,16 +61,17 @@ PptpSettingWidget::PptpSettingWidget(const NetworkManager::VpnSetting::Ptr &sett
     layout->addWidget(d->advancedWid);
     d->advancedDlg->setLayout(layout);
     QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel, d->advancedDlg);
-    connect(buttons, SIGNAL(accepted()), d->advancedDlg, SLOT(accept()));
-    connect(buttons, SIGNAL(rejected()), d->advancedDlg, SLOT(reject()));
+    connect(buttons, &QDialogButtonBox::accepted, d->advancedDlg, &QDialog::accept);
+    connect(buttons, &QDialogButtonBox::rejected, d->advancedDlg, &QDialog::reject);
     layout->addWidget(buttons);
 
-    connect(d->ui.edt_gateway, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
+    connect(d->ui.edt_gateway, &QLineEdit::textChanged, this, &PptpSettingWidget::slotWidgetChanged);
 
     KAcceleratorManager::manage(this);
 
-    if (d->setting)
+    if (d->setting) {
         loadConfig(d->setting);
+    }
 }
 
 PptpSettingWidget::~PptpSettingWidget()
@@ -85,10 +88,11 @@ void PptpSettingWidget::passwordTypeChanged(int index)
 void PptpSettingWidget::setShowPassword(bool show)
 {
     Q_D(PptpSettingWidget);
-    if (show)
+    if (show) {
         d->ui.edt_password->setEchoMode(QLineEdit::Normal);
-    else
+    } else {
         d->ui.edt_password->setEchoMode(QLineEdit::Password);
+    }
 }
 
 void PptpSettingWidget::doAdvancedDialog()
@@ -105,29 +109,20 @@ void PptpSettingWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
 
     // General settings
     const NMStringMap dataMap = d->setting->data();
-    const NMStringMap secrets = d->setting->secrets();
 
     // Authentication
     const QString sGateway = dataMap[NM_PPTP_KEY_GATEWAY];
-    if (!sGateway.isEmpty())
-    {
+    if (!sGateway.isEmpty()) {
         d->ui.edt_gateway->setText(sGateway);
     }
 
     const QString sLogin = dataMap[NM_PPTP_KEY_USER];
-    if (!sLogin.isEmpty())
-    {
+    if (!sLogin.isEmpty()) {
         d->ui.edt_login->setText(sLogin);
     }
 
-    const QString sPassword = secrets[NM_PPTP_KEY_PASSWORD];
-    if (!sPassword.isEmpty()) {
-        d->ui.edt_password->setText(sPassword);
-    }
-
     const QString sDomain = dataMap[NM_PPTP_KEY_DOMAIN];
-    if (!sDomain.isEmpty())
-    {
+    if (!sDomain.isEmpty()) {
         d->ui.edt_ntDomain->setText(sDomain);
     }
 
@@ -163,11 +158,9 @@ void PptpSettingWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
         d->advUi.gb_MPPE->setChecked(mppe || mppe40 || mppe128);
         if (mppe128) {
             d->advUi.cb_MPPECrypto->setCurrentIndex(1); // 128 bit
-        }
-        else if (mppe40) {
+        } else if (mppe40) {
             d->advUi.cb_MPPECrypto->setCurrentIndex(2); // 40 bit
-        }
-        else {
+        } else {
             d->advUi.cb_MPPECrypto->setCurrentIndex(0); // Any
         }
         d->advUi.cb_statefulEncryption->setChecked(mppe_stateful);
@@ -188,10 +181,24 @@ void PptpSettingWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
 
     // secrets
     const NetworkManager::Setting::SecretFlags type = (NetworkManager::Setting::SecretFlags)dataMap[NM_PPTP_KEY_PASSWORD"-flags"].toInt();
-    if (type & NetworkManager::Setting::AgentOwned || type & NetworkManager::Setting::None || !type) {
-        d->ui.edt_password->setText(secrets.value(QLatin1String(NM_PPTP_KEY_PASSWORD)));
-    }
     fillOnePasswordCombo(d->ui.cmbPasswordStorage, type);
+
+    loadSecrets(setting);
+}
+
+void PptpSettingWidget::loadSecrets(const NetworkManager::Setting::Ptr &setting)
+{
+    Q_D(PptpSettingWidget);
+
+    NetworkManager::VpnSetting::Ptr vpnSetting = setting.staticCast<NetworkManager::VpnSetting>();
+
+    if (vpnSetting) {
+        const NMStringMap secrets = vpnSetting->secrets();
+        const QString keyPassword = secrets.value(QLatin1String(NM_PPTP_KEY_PASSWORD));
+        if (!keyPassword.isEmpty()) {
+            d->ui.edt_password->setText(keyPassword);
+        }
+    }
 }
 
 QVariantMap PptpSettingWidget::setting(bool agentOwned) const
@@ -223,46 +230,40 @@ QVariantMap PptpSettingWidget::setting(bool agentOwned) const
     QListWidgetItem * item = 0;
     item = d->advUi.listWidget->item(0); // PAP
     const QString yesString = QLatin1String("yes");
-    if (item->checkState() == Qt::Unchecked)
+    if (item->checkState() == Qt::Unchecked) {
         data.insert(NM_PPTP_KEY_REFUSE_PAP, yesString);
+    }
     item = d->advUi.listWidget->item(1); // CHAP
-    if (item->checkState() == Qt::Unchecked)
+    if (item->checkState() == Qt::Unchecked) {
         data.insert(NM_PPTP_KEY_REFUSE_CHAP, yesString);
+    }
     item = d->advUi.listWidget->item(2); // MSCHAP
-    if (item->checkState() == Qt::Unchecked)
+    if (item->checkState() == Qt::Unchecked) {
         data.insert(NM_PPTP_KEY_REFUSE_MSCHAP, yesString);
+    }
     item = d->advUi.listWidget->item(3); // MSCHAPv2
-    if (item->checkState() == Qt::Unchecked)
+    if (item->checkState() == Qt::Unchecked) {
         data.insert(NM_PPTP_KEY_REFUSE_MSCHAPV2, yesString);
+    }
     item = d->advUi.listWidget->item(4); // EAP
-    if (item->checkState() == Qt::Unchecked)
+    if (item->checkState() == Qt::Unchecked) {
         data.insert(NM_PPTP_KEY_REFUSE_EAP, yesString);
+    }
 
     // Cryptography and compression
-    if (d->advUi.gb_MPPE->isChecked())
-    {
+    if (d->advUi.gb_MPPE->isChecked()) {
         int index = d->advUi.cb_MPPECrypto->currentIndex();
 
-        switch (index)
-        {
-            case 0:
-                {
-                    // "Any"
-                    data.insert(NM_PPTP_KEY_REQUIRE_MPPE, yesString);
-                }
-                break;
-            case 1:
-                {
-                    // "128 bit"
-                    data.insert(NM_PPTP_KEY_REQUIRE_MPPE_128, yesString);
-                }
-                break;
-            case 2:
-                {
-                    // "40 bit"
-                    data.insert(NM_PPTP_KEY_REQUIRE_MPPE_40, yesString);
-                }
-                break;
+        switch (index) {
+        case 0:
+            data.insert(NM_PPTP_KEY_REQUIRE_MPPE, yesString);
+            break;
+        case 1:
+            data.insert(NM_PPTP_KEY_REQUIRE_MPPE_128, yesString);
+            break;
+        case 2:
+            data.insert(NM_PPTP_KEY_REQUIRE_MPPE_40, yesString);
+            break;
         }
 
         if (d->advUi.cb_statefulEncryption->isChecked()) {
@@ -272,7 +273,6 @@ QVariantMap PptpSettingWidget::setting(bool agentOwned) const
 
     if (!d->advUi.cb_BSD->isChecked()) {
         data.insert(NM_PPTP_KEY_NOBSDCOMP, yesString);
-
     }
     if (!d->advUi.cb_deflate->isChecked()) {
         data.insert(NM_PPTP_KEY_NODEFLATE, yesString);
@@ -297,11 +297,11 @@ QVariantMap PptpSettingWidget::setting(bool agentOwned) const
 void PptpSettingWidget::fillOnePasswordCombo(QComboBox * combo, NetworkManager::Setting::SecretFlags type)
 {
     if (type.testFlag(NetworkManager::Setting::AgentOwned) || type.testFlag(NetworkManager::Setting::None)) { // store
-        combo->setCurrentIndex(0);
-    } else if (type.testFlag(NetworkManager::Setting::NotRequired)) { // not required
-        combo->setCurrentIndex(2);
+        combo->setCurrentIndex(SettingWidget::EnumPasswordStorageType::Store);
     } else if (type.testFlag(NetworkManager::Setting::NotSaved)) { // always ask
-        combo->setCurrentIndex(1);
+        combo->setCurrentIndex(SettingWidget::EnumPasswordStorageType::AlwaysAsk);
+    } else if (type.testFlag(NetworkManager::Setting::NotRequired)) { // not required
+        combo->setCurrentIndex(SettingWidget::EnumPasswordStorageType::NotRequired);
     }
 }
 
@@ -320,6 +320,7 @@ uint PptpSettingWidget::handleOnePasswordType(const QComboBox *combo, const QStr
     case 1:
         data.insert(key, QString::number(NetworkManager::Setting::NotSaved)); // always ask
         break;
+
     case 2:
         data.insert(key, QString::number(NetworkManager::Setting::NotRequired)); // not required
         break;
